SystemOrganization addCategory: #DirWalker!

Object subclass: #DirWalker
	instanceVariableNames: 'path filenames children'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DirWalker'!

!DirWalker commentStamp: 'PhilippeQuesnel 3/5/2014 20:10' prior: 0!
a DirWalkerNode represents a directory entry in a tree structure It reads a directory tree in memory.
It offers a walk method to traverse the tree

!

!DirWalker class methodsFor: 'instance creation' stamp: 'PhilippeQuesnel 3/5/2014 20:41'!
newFromStringPath: stringPath
	""

	| dirFileRef |
	dirFileRef := stringPath asFileReference.
	dirFileRef isDirectory ifFalse: [ self error: 'Not a directory: ', stringPath ].
	
	^ self new readAt: dirFileRef.
	! !

!DirWalker methodsFor: 'accessing' stamp: 'PhilippeQuesnel 3/5/2014 21:09'!
basename
	"returns the basename for this directory"

	^ path basename! !

!DirWalker methodsFor: 'private tree building' stamp: 'PhilippeQuesnel 3/5/2014 23:36'!
readAt: dirFileRef
	"reads directory, recursing into child dirs"

	path := dirFileRef path.
	filenames := dirFileRef fileNames.
	children := dirFileRef directories collect: [ :kidDirRef | self class new readAt: kidDirRef ]! !

!DirWalker methodsFor: 'navigating' stamp: 'PhilippeQuesnel 3/6/2014 23:23'!
walkWith: visitor
	visitor enterDirectory: self basename.
	children do: [ :kid | kid walkWith: visitor ].
	filenames do: [ :filename | visitor processFile: filename ].
	visitor exitDirectory: self basename! !

Object subclass: #IDirWalkerVisitor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DirWalker'!

!IDirWalkerVisitor commentStamp: 'PhilippeQuesnel 3/6/2014 23:47' prior: 0!
An IDirWalkerVisistor is the visitor 'interface' for the walk method of DirWalker
!

IDirWalkerVisitor subclass: #DirWalkPrintVisitor
	instanceVariableNames: 'level'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DirWalker'!

!DirWalkPrintVisitor commentStamp: 'PhilippeQuesnel 3/6/2014 22:58' prior: 0!
A DirWalkPrintVisitor prints out the directory structure indented on transcript!

!DirWalkPrintVisitor methodsFor: 'navigation' stamp: 'PhilippeQuesnel 3/6/2014 23:41'!
enterDirectory: name
	self indent.
	Transcript
		show: '+', name, '/'; 
		cr.
	level := level + 1! !

!DirWalkPrintVisitor methodsFor: 'navigation' stamp: 'PhilippeQuesnel 3/6/2014 23:14'!
exitDirectory: name
	level := level - 1! !

!DirWalkPrintVisitor methodsFor: 'private - utilities' stamp: 'PhilippeQuesnel 3/6/2014 23:12'!
indent
	Transcript show: self spaces.
! !

!DirWalkPrintVisitor methodsFor: 'initialization' stamp: 'PhilippeQuesnel 3/6/2014 23:08'!
initialize
	level := 0.! !

!DirWalkPrintVisitor methodsFor: 'navigation' stamp: 'PhilippeQuesnel 3/6/2014 23:14'!
processFile: name
	self indent.
	Transcript
		show: name;
		cr! !

!DirWalkPrintVisitor methodsFor: 'private - utilities' stamp: 'PhilippeQuesnel 3/6/2014 23:24'!
spaces
	^ String new padRightTo: (level * 3).! !

!IDirWalkerVisitor methodsFor: 'navigation' stamp: 'PhilippeQuesnel 3/6/2014 22:55'!
enterDirectory: name
	^ self subclassResponsibility.! !

!IDirWalkerVisitor methodsFor: 'navigation' stamp: 'PhilippeQuesnel 3/6/2014 22:56'!
exitDirectory: name
	^ self subclassResponsibility.! !

!IDirWalkerVisitor methodsFor: 'navigation' stamp: 'PhilippeQuesnel 3/6/2014 22:56'!
processFile: name
	^ self subclassResponsibility.! !
